/*
  THIS PROGRAM DISCLOSES MATERIAL PROTECTABLE UNDER COPYRIGHT
  LAWS OF THE UNITED STATES.  FOR LICENSING INFORMATION CONTACT:

  Christian Bischof or Lucas Roh, Mathematics and Computer Science Division,
  Argonne National Laboratory, 9700 S. Cass Avenue, Argonne IL 60439, 
  {bischof,roh}@mcs.anl.gov.
*/


#include <stdio.h>
#include <stdlib.h>

#if !defined(AD_GRAD_H)
#   define AD_GRAD_H
#   if defined(AD_USE_MPI)
#       include "ad_mpi.h"
#   endif
#   include <string.h>
    
#if ad_GRAD_PTR
#include "ad_grad_daxpy.h"
#else
#include "ad_grad_macro_axpys.h"
#endif
    
    extern int ad_grad_size;
    extern int ad_total_grad_size;   /*only used when generating MPI programs*/
    extern int ad_grad_size_shadow;

#   if defined(__cplusplus)
        extern "C" {
#   endif
    
#if ad_GRAD_PTR



#define AD_VAR_INIT(arg) \
    DERIV_grad(arg) = 0;

#define AD_ARRAY_INIT(arg) \
    memset(arg, '\0', sizeof(arg))

#define AD_VAR_FINAL(arg) \
    ad_grad_daxpy_free(&DERIV_grad(arg))

#define AD_ARRAY_FINAL(arg)\
{   int i;\
    for (i = 0; i < sizeof (arg) / sizeof (arg[0]); i++)\
        ad_grad_daxpy_free(&DERIV_grad(arg[i]));\
}

#define ad_AD_GradInit(n) \
    { \
        ad_grad_size = n; \
        ad_grad_size_shadow = 0; \
        ad_grad_daxpy_init(n); \
    }

#define ad_AD_GradFinal() \
    { \
        ad_grad_daxpy_final(); \
    }

#define ad_AD_ClearGrad(gz)\
        INVALIDATE(gz);

#define ad_AD_InitGrad(gz)\
        AD_VAR_INIT(*gz)

#define ad_AD_CopyGrad(gz,gx) \
        ad_grad_daxpy_copy(gz,gx);

#define ad_AD_GetTotalGradSize() 	ad_grad_size
#define ad_AD_SetTotalGradSize(x)    	/*don't support*/
#define ad_AD_SetIndepDone()            ad_AD_CommitShadowVar()
#define ad_AD_ResetIndep() 		ad_AD_ResetShadowVar()

#define ad_AD_ExtractGrad(a, var) \
    { \
        int pOsItIoN; \
	double* gRaDiE = DERIV_grad(*(var));\
        if (gRaDiE) {\
            for (pOsItIoN = 0; pOsItIoN < ad_grad_size; pOsItIoN++) {\
                (a)[pOsItIoN] = gRaDiE[pOsItIoN];  \
            }\
        }\
        else {\
            for (pOsItIoN = 0; pOsItIoN < ad_grad_size; pOsItIoN++) {\
                (a)[pOsItIoN] = 0.0;\
            }\
        }\
    }
#   define ad_AD_ExtractVal(a, var) \
    { \
        a = DERIV_val(*var); \
    }

#define ad_AD_SetGrad(a, var) \
    { \
        int pOsItIoN; \
        VALIDATE(var);\
        for (pOsItIoN = 0; pOsItIoN < ad_grad_size; pOsItIoN++) {\
            DERIV_grad(*var)[pOsItIoN] = (a)[pOsItIoN];  \
        }\
    }

#define ad_AD_SetGradVal(var, a, i) \
    { \
        int pOsItIoN2; \
        VALIDATE(var);\
        for (pOsItIoN2 = 0; pOsItIoN2 < ad_grad_size; pOsItIoN2++) {\
	    if (pOsItIoN2 == i) {\
                DERIV_grad(*var)[pOsItIoN2] = a;  \
            }\
	    else {\
                DERIV_grad(*var)[pOsItIoN2] = 0;\
            }\
        }\
    }

/* ad_AD_SetIndep assumes that the gradient pointers are currently uninitialized */
/* var is a DERIV_TYPE pointer */
#define ad_AD_SetIndep(var) \
    { \
        int pOsItIoN = ad_AD_IncrShadowVar(); \
        ad_AD_InitGrad(var); \
        DERIV_grad(*var) = (double*)malloc(ad_GRAD_MAX*sizeof(double)); \
        if (pOsItIoN > ad_GRAD_MAX) {\
            fprintf (stderr, "ad_AD_SetIndep() Error: the number of " \
		     "independent variables %d exceeds the max (GRAD_MAX)!\n",\
		     pOsItIoN); \
            fflush(stderr);  \
            abort();  \
        }\
        ad_AD_SetGradVal(var, 1, pOsItIoN); \
    }

#define ad_AD_SetIndepArray(vars, size) \
    { \
        int iWiLlNeVeRCoNfLiCt; \
        for (iWiLlNeVeRCoNfLiCt = 0; iWiLlNeVeRCoNfLiCt < size; \
	       iWiLlNeVeRCoNfLiCt++) { \
            ad_AD_SetIndep(&((vars)[iWiLlNeVeRCoNfLiCt])); \
        } \
    }






#elif ad_GRAD_SPARSE_PTR

#define ad_AD_GradInit(n) \
    { \
        ad_grad_size = n; \
        ad_grad_size_shadow = 0; \
        ad_grad_daxpy_init(n); \
    }

#define ad_AD_GradFinal() \
    { \
        ad_grad_daxpy_final(); \
    }

#define ad_AD_ClearGrad(gz)\
        ad_grad_daxpy_free(&gz);

#define ad_AD_CopyGrad(gz,gx) \
        ad_grad_daxpy_copy(gz,gx);

#define ad_AD_GetTotalGradSize() 	ad_grad_size
#define ad_AD_SetTotalGradSize(x)    	/*don't support*/
#define ad_AD_SetIndepDone() 		ad_AD_CommitShadowVar()
#define ad_AD_ResetIndep() 		ad_AD_ResetShadowVar()

#define ad_AD_ExtractGrad(a, var) \
    { \
        int pOsItIoN; \
	double* gRaDiE = DERIV_grad(var);\
        if (gRaDiE) {\
            for (pOsItIoN = 0; pOsItIoN < ad_grad_size; pOsItIoN++) {\
                (a)[pOsItIoN] = gRaDiE[pOsItIoN];  \
            }\
        }\
        else {\
            for (pOsItIoN = 0; pOsItIoN < ad_grad_size; pOsItIoN++) {\
                (a)[pOsItIoN] = 0.0;\
            }\
        }\
    }
#   define ad_AD_ExtractVal(a, var) \
    { \
        a = DERIV_val(var); \
     }
#define ad_AD_SetGrad(a, var) \
    { \
        int pOsItIoN; \
        VALIDATE(&DERIV_grad(var));\
        for (pOsItIoN = 0; pOsItIoN < ad_grad_size; pOsItIoN++) {\
            DERIV_grad(var)[pOsItIoN] = (a)[pOsItIoN];  \
        }\
    }

#define ad_AD_SetGradVal(var, a, i) \
    { \
        int pOsItIoN2; \
        VALIDATE(&DERIV_grad(var));\
        for (pOsItIoN2 = 0; pOsItIoN2 < ad_grad_size; pOsItIoN2++) {\
	    if (pOsItIoN2 == i) {\
                DERIV_grad(var)[pOsItIoN2] = a;  \
            }\
	    else {\
                DERIV_grad(var)[pOsItIoN2] = 0.0;\
            }\
        }\
    }

#define ad_AD_SetIndep(var) \
    { \
        int pOsItIoN = ad_AD_IncrShadowVar(); \
        VALIDATE(&DERIV_grad(var));\
        if (pOsItIoN > ad_GRAD_MAX) {\
            fprintf (stderr, "ad_AD_SetIndep() Error: the number of " \
		     "independent variables %d exceeds the max (GRAD_MAX)!\n",\
		     pOsItIoN); \
            fflush(stderr);  \
            abort();  \
        }\
        ad_AD_SetGradVal(var, 1.0, pOsItIoN); \
    }

#define ad_AD_SetIndepArray(vars, size) \
    { \
        int iWiLlNeVeRCoNfLiCt; \
        for (iWiLlNeVeRCoNfLiCt = 0; iWiLlNeVeRCoNfLiCt < size; \
	       iWiLlNeVeRCoNfLiCt++) { \
            ad_AD_SetIndep((vars)[iWiLlNeVeRCoNfLiCt]); \
        } \
    }





#else
#define ad_AD_GradInitMPI(pargc, pargv) \
    { \
        ad_mpi_init(pargc, pargv, &ad_total_grad_size); \
    }


#define ad_AD_GradFinalMPI() \
    { \
        ad_mpi_final(); \
    }

#define ad_AD_GradFinal() \
    { \
        ad_grad_size = 0; \
    }



#define ad_AD_GradInit(n) \
    { \
	if (n == -1) \
	   ad_grad_size = ad_GRAD_MAX; \
	else \
           ad_grad_size = n; \
        ad_grad_size_shadow = 0; \
    }


#define ad_AD_ClearGrad(gz) memset((char*)(DERIV_grad(*gz)), 0, ad_GRAD_MAX*sizeof(double)); 

#define ad_AD_InitGrad(gz) memset((char*)(DERIV_grad(*gz)), 0, ad_GRAD_MAX*sizeof(double));

#define ad_AD_CopyGrad(gz,gx) \
    {\
        int iWiLlNeVeRCoNfLiCt0;\
        for (iWiLlNeVeRCoNfLiCt0 = 0 ; iWiLlNeVeRCoNfLiCt0 < ad_GRAD_MAX;\
	     iWiLlNeVeRCoNfLiCt0++) {\
            gz[iWiLlNeVeRCoNfLiCt0] = gx[iWiLlNeVeRCoNfLiCt0];\
        }\
    }


#if defined(AD_USE_MPI)

#   define ad_AD_GetTotalGradSize() ad_total_grad_size
#   define ad_AD_SetTotalGradSize(x) ad_total_grad_size = x
#   define ad_AD_ExtractGrad(a, var) \
    { \
        ad_mpi_gather(DERIV_grad(var), a); \
    }
#   define ad_AD_ExtractVal(a, var) \
    { \
	ad_mpi_gather(&(DERIV_val(var)), &(a)); \
    }
#   define ad_AD_SetIndepDone() ad_AD_CommitShadowVar()
#   define ad_AD_SetIndep(var) \
    { \
        int pOsItIoN = ad_total_grad_size++; \
        ad_AD_ClearGrad(&var); \
        if (pOsItIoN >= ad_mpi_vect_my_disp && \
	    pOsItIoN < ad_mpi_vect_my_disp+ad_mpi_vect_my_len) {\
            int pOsItIoN2 = ad_AD_IncrShadowVar();\
            if (pOsItIoN2 > ad_GRAD_MAX) {\
                fprintf (stderr, "ad_AD_SetIndep() Error: the number of independent variables per processor %d exceeds the max (GRAD_MAX)!\n", pOsItIoN2);\
                fflush(stderr);  \
                abort();  \
            }\
            DERIV_grad(var)[pOsItIoN2] = 1; \
        }\
    }

#   define ad_AD_SetIndepArray(vars, size) \
    { \
        int iWiLlNeVeRCoNfLiCt; \
        for (iWiLlNeVeRCoNfLiCt = 0; iWiLlNeVeRCoNfLiCt < size; \
	       iWiLlNeVeRCoNfLiCt++) { \
            ad_AD_ClearGrad(&((vars)[iWiLlNeVeRCoNfLiCt])); \
            int pOsItIoN = ad_total_grad_size++; \
            if (pOsItIoN >= ad_mpi_vect_my_disp && \
	             pOsItIoN < ad_mpi_vect_my_disp+ad_mpi_vect_my_len) {\
                DERIV_grad((vars)[iWiLlNeVeRCoNfLiCt])[ad_AD_IncrShadowVar()]=1;\
            } \
        } \
    }


#else /* !defined(AD_USE_MPI)*/

#   define ad_AD_GetTotalGradSize() ad_grad_size
#   define ad_AD_SetTotalGradSize(x) \
    { \
	if (x > ad_GRAD_MAX) {\
                fprintf (stderr, "ad_AD_SetTotalGradSize() Error: the number of independent variables %d exceeds the max (GRAD_MAX)!\n", x);\
                fflush(stderr);  \
                abort();  \
        }\
        ad_grad_size_shadow = x;\
        ad_grad_size = x; \
    }

#   define ad_AD_IncrementTotalGradSize(x) \
    { \
         if (x + ad_grad_size_shadow > ad_GRAD_MAX) {\
                fprintf (stderr, "ad_AD_IncrementTotalGradSize() Error: the number of independent variables %d exceeds the max (GRAD_MAX)!\n", x + ad_grad_size_shadow);\
                fflush(stderr);  \
                abort();  \
        }\
        ad_grad_size_shadow += x;\
    }

#   define ad_AD_ExtractGrad(a, var) \
    { \
        int pOsItIoN; \
        for (pOsItIoN = 0; pOsItIoN < ad_grad_size; pOsItIoN++) {\
            (a)[pOsItIoN] = DERIV_grad(*var)[pOsItIoN];  \
        }\
    }
#   define ad_AD_ExtractVal(a, var) \
    { \
	a = DERIV_val(var); \
    }
#   define ad_AD_SetGrad(a, var) \
    { \
        int pOsItIoN; \
        for (pOsItIoN = 0; pOsItIoN < ad_grad_size; pOsItIoN++) {\
            DERIV_grad(var)[pOsItIoN] = (a)[pOsItIoN];  \
        }\
    }

#   define ad_AD_SetGradAt(a, index, var) \
    { \
        DERIV_grad(var)[index] = a; \
    }

#   define ad_AD_GetGradAt(a, index, var) \
    { \
        a = DERIV_grad(var)[index]; \
    }

#   define ad_AD_SetIndepDone() ad_AD_CommitShadowVar()
#   define ad_AD_ResetIndep() ad_AD_ResetShadowVar()
#   define ad_AD_SetIndep(var) \
    { \
        int pOsItIoN = ad_AD_IncrShadowVar(); \
        if (pOsItIoN > ad_GRAD_MAX) {\
            fprintf (stderr, "ad_AD_SetIndep() Error: the number of " \
		     "independent variables %d exceeds the max (GRAD_MAX)!\n",\
		     pOsItIoN); \
            fflush(stderr);  \
            abort();  \
        }\
        ad_AD_ClearGrad(DERIV_grad(var)); \
        DERIV_grad(var)[pOsItIoN] = 1; \
    }
#   define ad_AD_SetIndepArray(vars, size) \
    { \
        int iWiLlNeVeRCoNfLiCt; \
        for (iWiLlNeVeRCoNfLiCt = 0; iWiLlNeVeRCoNfLiCt < size; \
	       iWiLlNeVeRCoNfLiCt++) { \
            ad_AD_ClearGrad(&((vars)[iWiLlNeVeRCoNfLiCt])); \
            DERIV_grad((vars)[iWiLlNeVeRCoNfLiCt])[ad_AD_IncrShadowVar()] = 1; \
        } \
    }

/* Array of colors should be the same length as the vars array */
#   define ad_AD_SetIndepArrayColored(vars, size, colors) \
    { \
        int iWiLlNeVeRCoNfLiCt; \
        for (iWiLlNeVeRCoNfLiCt = 0; iWiLlNeVeRCoNfLiCt < size; \
	       iWiLlNeVeRCoNfLiCt++) { \
            ad_AD_ClearGrad(DERIV_grad((vars)[iWiLlNeVeRCoNfLiCt])); \
            DERIV_grad((vars)[iWiLlNeVeRCoNfLiCt])[ad_grad_size_shadow+colors[iWiLlNeVeRCoNfLiCt]] = 1; \
        } \
    }

/* values array is the same length as vars */
#   define ad_AD_SetIndepVector(vars, size, values) \
    { \
        int iWiLlNeVeRCoNfLiCt; \
        for (iWiLlNeVeRCoNfLiCt = 0; iWiLlNeVeRCoNfLiCt < size; \
	       iWiLlNeVeRCoNfLiCt++) { \
            ad_AD_ClearGrad(DERIV_grad((vars)[iWiLlNeVeRCoNfLiCt])); \
            DERIV_grad((vars)[iWiLlNeVeRCoNfLiCt])[ad_grad_size_shadow] = values[iWiLlNeVeRCoNfLiCt]; \
        } \
        ad_grad_size_shadow++; \
    }

#endif /*defined(AD_USE_MPI)*/



#endif


    
    int ad_AD_IncrShadowVar();

    void ad_AD_CommitShadowVar();

    void ad_AD_ResetShadowVar();

#   if defined(__cplusplus)
        }
#  endif
#endif /*AD_GRAD_H*/


