#include "hessdef.h"


void ad_fh_faddad (double c, double *g_c, double *h_c, double a, double *g_a, double *h_a, double b, double *g_b, double *h_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i] + g_b[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i] + h_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_faddbd (double c, double *g_c, double *h_c, double a, double *g_a, double *h_a, double b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_faddcd (double c, double *g_c, double *h_c, double a, double b, double *g_b, double *h_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_b[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fsubad (double c, double *g_c, double *h_c, double a, double *g_a, double *h_a, double b, double *g_b, double *h_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i] - g_b[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i] - h_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fsubbd (double c, double *g_c, double *h_c, double a, double *g_a, double *h_a, double b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fsubcd (double c, double *g_c, double *h_c, double a, double b, double *g_b, double *h_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = -g_b[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = -h_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fmulad (double c, double *g_c, double *h_c, double a, double *g_a, double *h_a, double b, double *g_b, double *h_b)
{

  int n, j, i;

  {
    n = 0;
    for (i = 0; i < hess_size_1; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    h_c[n] = b * h_a[n] + a * h_b[n] + g_a[i] * g_b[j] + g_a[j] * g_b[i];
	    n = n + 1;
	  }
      }
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = b * g_a[i] + a * g_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fmulbd (double c, double *g_c, double *h_c, double a, double *g_a, double *h_a, double b)
{

  int n, j, i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = b * g_a[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = b * h_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fmulcd (double c, double *g_c, double *h_c, double a, double b, double *g_b, double *h_b)
{

  int n, j, i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = a * g_b[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = a * h_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fdivad (double c, double *g_c, double *h_c, double a, double *g_a, double *h_a, double b, double *g_b, double *h_b)
{

  int n, j, i;
  double temp1, temp2, temp3;

  {
    temp1 = a / b;
    temp2 = 2.0 * temp1 / b;
    temp3 = 1.0 / b;
    n = 0;
    for (i = 0; i < hess_size_1; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    h_c[n] = temp3 * (h_a[n] - temp1 * h_b[n] + temp2 * g_b[i] * g_b[j] - temp3 * (g_a[i] * g_b[j] + g_a[j] * g_b[i]));
	    n = n + 1;
	  }
      }
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = temp3 * g_a[i] - temp1 * temp3 * g_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fdivbd (double c, double *g_c, double *h_c, double a, double *g_a, double *h_a, double b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i] / b;
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i] / b;
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fdivcd (double c, double *g_c, double *h_c, double a, double b, double *g_b, double *h_b)
{

  int n, j, i;
  double temp1, temp2, temp3;

  {
    temp1 = -a / (b * b);
    temp2 = 2.0 * temp1 / (b * b);
    temp3 = 1.0 / b;
    n = 0;
    for (i = 0; i < hess_size_1; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    h_c[n] = temp1 * h_b[n] + temp2 * g_b[i] * g_b[j];
	    n = n + 1;
	  }
      }
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = temp1 * g_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fcopyd (double c, double *g_c, double *h_c, double a, double *g_a, double *h_a)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fmind (double c, double *g_c, double *h_c, double a, double *g_a, double *h_a)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = -g_a[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = -h_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fzerod (double c, double *g_c, double *h_c)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = 0.0;
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = 0.0;
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fintrin1d (double fa, double faa, double c, double *g_c, double *h_c, double a, double *g_a, double *h_a)
{

  int n, j, i;
  double temp;

  {
    n = 0;
    for (i = 0; i < hess_size_1; i++)
      {
	temp = faa * g_a[i];
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    h_c[n] = fa * h_a[n] + temp * g_a[j];
	    n = n + 1;
	  }
      }
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = fa * g_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fintrin2d (double fa, double fb, double faa, double fab, double fbb, double c, double *g_c, double *h_c, double a, double *g_a, double *h_a, double b, double *g_b, double *h_b)
{

  int n, j, i;
  double temp1, temp2;

  {
    n = 0;
    for (i = 0; i < hess_size_1; i++)
      {
	temp1 = faa * g_a[i] + fab * g_b[i];
	temp2 = fab * g_a[i] + fbb * g_b[i];
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    h_c[n] = fa * h_a[n] + fb * h_b[n] + temp1 * g_a[j] + temp2 * g_b[j];
	    n = n + 1;
	  }
      }
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = fa * g_a[i] + fb * g_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_faddas (float c, float *g_c, float *h_c, float a, float *g_a, float *h_a, float b, float *g_b, float *h_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i] + g_b[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i] + h_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_faddbs (float c, float *g_c, float *h_c, float a, float *g_a, float *h_a, float b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_faddcs (float c, float *g_c, float *h_c, float a, float b, float *g_b, float *h_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_b[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fsubas (float c, float *g_c, float *h_c, float a, float *g_a, float *h_a, float b, float *g_b, float *h_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i] - g_b[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i] - h_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fsubbs (float c, float *g_c, float *h_c, float a, float *g_a, float *h_a, float b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fsubcs (float c, float *g_c, float *h_c, float a, float b, float *g_b, float *h_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = -g_b[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = -h_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fmulas (float c, float *g_c, float *h_c, float a, float *g_a, float *h_a, float b, float *g_b, float *h_b)
{

  int n, j, i;

  {
    n = 0;
    for (i = 0; i < hess_size_1; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    h_c[n] = b * h_a[n] + a * h_b[n] + g_a[i] * g_b[j] + g_a[j] * g_b[i];
	    n = n + 1;
	  }
      }
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = b * g_a[i] + a * g_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fmulbs (float c, float *g_c, float *h_c, float a, float *g_a, float *h_a, float b)
{

  int n, j, i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = b * g_a[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = b * h_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fmulcs (float c, float *g_c, float *h_c, float a, float b, float *g_b, float *h_b)
{

  int n, j, i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = a * g_b[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = a * h_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fdivas (float c, float *g_c, float *h_c, float a, float *g_a, float *h_a, float b, float *g_b, float *h_b)
{

  int n, j, i;
  float temp1, temp2, temp3;

  {
    temp1 = a / b;
    temp2 = 2.0 * temp1 / b;
    temp3 = 1.0 / b;
    n = 0;
    for (i = 0; i < hess_size_1; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    h_c[n] = temp3 * (h_a[n] - temp1 * h_b[n] + temp2 * g_b[i] * g_b[j] - temp3 * (g_a[i] * g_b[j] + g_a[j] * g_b[i]));
	    n = n + 1;
	  }
      }
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = temp3 * g_a[i] - temp1 * temp3 * g_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fdivbs (float c, float *g_c, float *h_c, float a, float *g_a, float *h_a, float b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i] / b;
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i] / b;
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fdivcs (float c, float *g_c, float *h_c, float a, float b, float *g_b, float *h_b)
{

  int n, j, i;
  float temp1, temp2, temp3;

  {
    temp1 = -a / (b * b);
    temp2 = 2.0 * temp1 / (b * b);
    temp3 = 1.0 / b;
    n = 0;
    for (i = 0; i < hess_size_1; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    h_c[n] = temp1 * h_b[n] + temp2 * g_b[i] * g_b[j];
	    n = n + 1;
	  }
      }
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = temp1 * g_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fcopys (float c, float *g_c, float *h_c, float a, float *g_a, float *h_a)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = g_a[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = h_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fmins (float c, float *g_c, float *h_c, float a, float *g_a, float *h_a)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = -g_a[i];
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = -h_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fzeros (float c, float *g_c, float *h_c)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = 0.0;
      }
    for (i = 0; i < hess_size_2; i++)
      {
	h_c[i] = 0.0;
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fintrin1s (float fa, float faa, float c, float *g_c, float *h_c, float a, float *g_a, float *h_a)
{

  int n, j, i;
  float temp;

  {
    n = 0;
    for (i = 0; i < hess_size_1; i++)
      {
	temp = faa * g_a[i];
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    h_c[n] = fa * h_a[n] + temp * g_a[j];
	    n = n + 1;
	  }
      }
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = fa * g_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_fintrin2s (float fa, float fb, float faa, float fab, float fbb, float c, float *g_c, float *h_c, float a, float *g_a, float *h_a, float b, float *g_b, float *h_b)
{

  int n, j, i;
  float temp1, temp2;

  {
    n = 0;
    for (i = 0; i < hess_size_1; i++)
      {
	temp1 = faa * g_a[i] + fab * g_b[i];
	temp2 = fab * g_a[i] + fbb * g_b[i];
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    h_c[n] = fa * h_a[n] + fb * h_b[n] + temp1 * g_a[j] + temp2 * g_b[j];
	    n = n + 1;
	  }
      }
    for (i = 0; i < hess_size_1; i++)
      {
	g_c[i] = fa * g_a[i] + fb * g_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpinitd (int ldg, int len, int n, double lg_c[5], double lh_c[5][5])
{

  int i;

  {
    n = n - 1;
    for (i = 0; i < len; i++)
      {
	lg_c[i] = 0.0;
      }
    lg_c[n] = 1.0;
  }
}
#include "hessdef.h"


void 
ad_h_fpadda0d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] + lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j] + lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpadda1d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] + lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpadda2d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] + lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpadda3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] + lg_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpaddb1d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b)
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpaddb3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b)
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpaddc2d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpaddc3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double b, double lg_b[5], double lh_b[5][5])
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsuba0d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] - lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j] - lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsuba1d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] - lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsuba2d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] - lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = -lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsuba3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] - lg_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsubb1d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b)
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsubb3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b)
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsubc2d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = -lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = -lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsubc3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double b, double lg_b[5], double lh_b[5][5])
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = -lg_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmula0d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i] + a * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = b * lh_a[i][j] + a * lh_b[i][j] + lg_a[i] * lg_b[j] + lg_a[j] * lg_b[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmula1d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i] + a * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = b * lh_a[i][j] + lg_a[i] * lg_b[j] + lg_a[j] * lg_b[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmula2d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i] + a * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = a * lh_b[i][j] + lg_a[i] * lg_b[j] + lg_a[j] * lg_b[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmula3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i] + a * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lg_a[i] * lg_b[j] + lg_a[j] * lg_b[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmulb1d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b)
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = b * lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmulb3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b)
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmulc2d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = a * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = a * lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmulc3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double b, double lg_b[5], double lh_b[5][5])
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = a * lg_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdiva0d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = (lg_a[i] - c * lg_b[i]) / b;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (lh_a[i][j] - lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j] - lh_b[i][j] * c) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdiva1d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = (lg_a[i] - c * lg_b[i]) / b;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (lh_a[i][j] - lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j]) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdiva2d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = (lg_a[i] - c * lg_b[i]) / b;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (-lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j] - lh_b[i][j] * c) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdiva3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = (lg_a[i] - c * lg_b[i]) / b;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (-lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j]) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdivb1d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b)
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] / b;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j] / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdivb3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5], double b)
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] / b;
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdivc2d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;
  double temp;

  {
    temp = -c / b;
    for (i = 0; i < len; i++)
      {
	lg_c[i] = temp * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (-lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j] - c * lh_b[i][j]) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdivc3d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double b, double lg_b[5], double lh_b[5][5])
{

  int j, i;
  double temp;

  {
    temp = -c / b;
    for (i = 0; i < len; i++)
      {
	lg_c[i] = temp * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (-lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j]) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmin0d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = -lg_a[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = -lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmin1d (int ldg, int len, double c, double lg_c[5], double lh_c[5][5], double a, double lg_a[5], double lh_a[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = -lg_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpzerod (int ldg, int len, double lg_c[5], double lh_c[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = 0.0;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = 0.0;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpadda0s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] + lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j] + lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpadda1s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] + lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpadda2s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] + lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpadda3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] + lg_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpaddb1s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b)
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpaddb3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b)
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpaddc2s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpaddc3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float b, float lg_b[5], float lh_b[5][5])
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsuba0s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] - lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j] - lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsuba1s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] - lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsuba2s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] - lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = -lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsuba3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] - lg_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsubb1s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b)
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsubb3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b)
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsubc2s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = -lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = -lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpsubc3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float b, float lg_b[5], float lh_b[5][5])
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = -lg_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmula0s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i] + a * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = b * lh_a[i][j] + a * lh_b[i][j] + lg_a[i] * lg_b[j] + lg_a[j] * lg_b[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmula1s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i] + a * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = b * lh_a[i][j] + lg_a[i] * lg_b[j] + lg_a[j] * lg_b[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmula2s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i] + a * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = a * lh_b[i][j] + lg_a[i] * lg_b[j] + lg_a[j] * lg_b[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmula3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i] + a * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lg_a[i] * lg_b[j] + lg_a[j] * lg_b[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmulb1s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b)
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = b * lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmulb3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b)
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = b * lg_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmulc2s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = a * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = a * lh_b[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpinits (int ldg, int len, int n, float lg_c[5], float lh_c[5][5])
{

  int i;

  {
    n = n - 1;
    for (i = 0; i < len; i++)
      {
	lg_c[i] = 0.0;
      }
    lg_c[n] = 1.0;
  }
}
#include "hessdef.h"


void 
ad_h_fpmulc3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float b, float lg_b[5], float lh_b[5][5])
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = a * lg_b[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdiva0s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = (lg_a[i] - c * lg_b[i]) / b;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (lh_a[i][j] - lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j] - lh_b[i][j] * c) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdiva1s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = (lg_a[i] - c * lg_b[i]) / b;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (lh_a[i][j] - lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j]) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdiva2s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = (lg_a[i] - c * lg_b[i]) / b;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (-lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j] - lh_b[i][j] * c) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdiva3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = (lg_a[i] - c * lg_b[i]) / b;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (-lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j]) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdivb1s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b)
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] / b;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = lh_a[i][j] / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdivb3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5], float b)
{

  int i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = lg_a[i] / b;
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdivc2s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;
  float temp;

  {
    temp = -c / b;
    for (i = 0; i < len; i++)
      {
	lg_c[i] = temp * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (-lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j] - c * lh_b[i][j]) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpdivc3s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float b, float lg_b[5], float lh_b[5][5])
{

  int j, i;
  float temp;

  {
    temp = -c / b;
    for (i = 0; i < len; i++)
      {
	lg_c[i] = temp * lg_b[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = (-lg_b[j] * lg_c[i] - lg_b[i] * lg_c[j]) / b;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmin0s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = -lg_a[i];
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = -lh_a[i][j];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpmin1s (int ldg, int len, float c, float lg_c[5], float lh_c[5][5], float a, float lg_a[5], float lh_a[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = -lg_a[i];
      }
  }
}
#include "hessdef.h"


void 
ad_h_fpzeros (int ldg, int len, float lg_c[5], float lh_c[5][5])
{

  int j, i;

  {
    for (i = 0; i < len; i++)
      {
	lg_c[i] = 0.0;
      }
    for (i = 0; i < len; i++)
      {
	for (j = 0; j < i + (1 - 0); j++)
	  {
	    lh_c[i][j] = 0.0;
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumg1d (int zero, double lg1, double *g_c, double *h_c, double *g_a, double *h_a)
{

  int n, j, i;

  {
    if (zero == 0)
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_c[i] = g_c[i] + lg1 * g_a[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_c[i] = h_c[i] + lg1 * h_a[i];
	  }
      }
    else
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_c[i] = lg1 * g_a[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_c[i] = lg1 * h_a[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumg2d (int zero, double lg1, double lg2, double *g_c, double *h_c, double *g_a, double *h_a, double *g_b, double *h_b)
{

  int n, j, i;

  {
    if (zero == 0)
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_c[i] = g_c[i] + lg1 * g_a[i] + lg2 * g_b[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_c[i] = h_c[i] + lg1 * h_a[i] + lg2 * h_b[i];
	  }
      }
    else
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_c[i] = lg1 * g_a[i] + lg2 * g_b[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_c[i] = lg1 * h_a[i] + lg2 * h_b[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumg3d (int zero, double lg1, double lg2, double lg3, double *g_d, double *h_d, double *g_a, double *h_a, double *g_b, double *h_b, double *g_c, double *h_c)
{

  int n, j, i;

  {
    if (zero == 0)
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_d[i] = g_d[i] + lg1 * g_a[i] + lg2 * g_b[i] + lg3 * g_c[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_d[i] = h_d[i] + lg1 * h_a[i] + lg2 * h_b[i] + lg3 * h_c[i];
	  }
      }
    else
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_d[i] = lg1 * g_a[i] + lg2 * g_b[i] + lg3 * g_c[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_d[i] = lg1 * h_a[i] + lg2 * h_b[i] + lg3 * h_c[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh1d (double lh1, double *h_v0, double *g_v1)
{

  int n, j, i;
  double temp1;

  {
    if (lh1 != 0.0)
      {
	n = 0;
	for (i = 0; i < hess_size_1; i++)
	  {
	    temp1 = g_v1[i] * lh1;
	    for (j = 0; j < i + (1 - 0); j++)
	      {
		h_v0[n] = h_v0[n] + temp1 * g_v1[j];
		n = n + 1;
	      }
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh2d (double lh1, double lh2, double *h_v0, double *g_v1, double *g_v2)
{

  int iflag, n, j, i;
  double temp1, temp2;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      temp2 = g_v2[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh3d (double lh1, double lh2, double lh3, double *h_v0, double *g_v1, double *g_v2)
{

  int iflag, n, j, i;
  double temp1, temp2;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    if (lh3 != 0.0)
      {
	iflag = iflag + 4;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      temp2 = g_v2[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 4:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh3;
	      temp2 = g_v2[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v2[j] + temp2 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 5:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v2[i] * lh3;
	      temp2 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 6:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2 + g_v1[i] * lh3;
	      temp2 = g_v2[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v2[j] + temp2 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 7:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v2[i] * lh3;
	      temp2 = g_v2[i] * lh2 + g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh4d (double lh1, double *h_v0, double *g_v1, double *g_v2)
{

  int n, j, i;
  double temp1, temp2;

  {
    if (lh1 != 0.0)
      {
	n = 0;
	for (i = 0; i < hess_size_1; i++)
	  {
	    temp1 = g_v2[i] * lh1;
	    temp2 = g_v1[i] * lh1;
	    for (j = 0; j < i + (1 - 0); j++)
	      {
		h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		n = n + 1;
	      }
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh5d (double lh1, double lh2, double *h_v0, double *g_v1, double *g_v2, double *g_v3)
{

  int iflag, n, j, i;
  double temp1, temp2, temp3;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1;
	      temp2 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v3[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1 + g_v3[i] * lh2;
	      temp2 = g_v1[i] * lh1;
	      temp3 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh6d (double lh1, double lh2, double lh3, double *h_v0, double *g_v1, double *g_v2, double *g_v3, double *g_v4)
{

  int iflag, n, j, i;
  double temp1, temp2, temp3, temp4;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    if (lh3 != 0.0)
      {
	iflag = iflag + 4;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1;
	      temp2 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v3[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1 + g_v3[i] * lh2;
	      temp2 = g_v1[i] * lh1;
	      temp3 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 4:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v4[i] * lh3;
	      temp2 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v4[j];
		  n = n + 1;
		}
	    }
	}
      case 5:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1 + g_v4[i] * lh3;
	      temp2 = g_v1[i] * lh1;
	      temp3 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v4[j];
		  n = n + 1;
		}
	    }
	}
      case 6:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v3[i] * lh2 + g_v4[i] * lh3;
	      temp2 = g_v1[i] * lh2;
	      temp3 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v3[j] + temp3 * g_v4[j];
		  n = n + 1;
		}
	    }
	}
      case 7:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1 + g_v3[i] * lh2 + g_v4[i] * lh3;
	      temp2 = g_v1[i] * lh1;
	      temp3 = g_v1[i] * lh2;
	      temp4 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v3[j] + temp4 * g_v4[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh7d (double lh1, double lh2, double lh3, double *h_v0, double *g_v1, double *g_v2, double *g_v3)
{

  int iflag, n, j, i;
  double temp1, temp2, temp3, temp4;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    if (lh3 != 0.0)
      {
	iflag = iflag + 4;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v2[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 4:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v3[i] * lh3;
	      temp2 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 5:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v3[i] * lh3;
	      temp2 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 6:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2 + g_v3[i] * lh3;
	      temp2 = g_v1[i] * lh2;
	      temp3 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 7:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v2[i] * lh2 + g_v3[i] * lh3;
	      temp2 = g_v1[i] * lh2;
	      temp3 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh8d (double lh1, double lh2, double *h_v0, double *g_v1, double *g_v2)
{

  int iflag, n, j, i;
  double temp1, temp2;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v2[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumg1s (int zero, float lg1, float *g_c, float *h_c, float *g_a, float *h_a)
{

  int n, j, i;

  {
    if (zero == 0)
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_c[i] = g_c[i] + lg1 * g_a[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_c[i] = h_c[i] + lg1 * h_a[i];
	  }
      }
    else
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_c[i] = lg1 * g_a[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_c[i] = lg1 * h_a[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumg2s (int zero, float lg1, float lg2, float *g_c, float *h_c, float *g_a, float *h_a, float *g_b, float *h_b)
{

  int n, j, i;

  {
    if (zero == 0)
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_c[i] = g_c[i] + lg1 * g_a[i] + lg2 * g_b[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_c[i] = h_c[i] + lg1 * h_a[i] + lg2 * h_b[i];
	  }
      }
    else
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_c[i] = lg1 * g_a[i] + lg2 * g_b[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_c[i] = lg1 * h_a[i] + lg2 * h_b[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumg3s (int zero, float lg1, float lg2, float lg3, float *g_d, float *h_d, float *g_a, float *h_a, float *g_b, float *h_b, float *g_c, float *h_c)
{

  int n, j, i;

  {
    if (zero == 0)
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_d[i] = g_d[i] + lg1 * g_a[i] + lg2 * g_b[i] + lg3 * g_c[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_d[i] = h_d[i] + lg1 * h_a[i] + lg2 * h_b[i] + lg3 * h_c[i];
	  }
      }
    else
      {
	for (i = 0; i < hess_size_1; i++)
	  {
	    g_d[i] = lg1 * g_a[i] + lg2 * g_b[i] + lg3 * g_c[i];
	  }
	for (i = 0; i < hess_size_2; i++)
	  {
	    h_d[i] = lg1 * h_a[i] + lg2 * h_b[i] + lg3 * h_c[i];
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh1s (float lh1, float *h_v0, float *g_v1)
{

  int n, j, i;
  float temp1;

  {
    if (lh1 != 0.0)
      {
	n = 0;
	for (i = 0; i < hess_size_1; i++)
	  {
	    temp1 = g_v1[i] * lh1;
	    for (j = 0; j < i + (1 - 0); j++)
	      {
		h_v0[n] = h_v0[n] + temp1 * g_v1[j];
		n = n + 1;
	      }
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh2s (float lh1, float lh2, float *h_v0, float *g_v1, float *g_v2)
{

  int iflag, n, j, i;
  float temp1, temp2;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      temp2 = g_v2[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh3s (float lh1, float lh2, float lh3, float *h_v0, float *g_v1, float *g_v2)
{

  int iflag, n, j, i;
  float temp1, temp2;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    if (lh3 != 0.0)
      {
	iflag = iflag + 4;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      temp2 = g_v2[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 4:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh3;
	      temp2 = g_v2[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v2[j] + temp2 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 5:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v2[i] * lh3;
	      temp2 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 6:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2 + g_v1[i] * lh3;
	      temp2 = g_v2[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v2[j] + temp2 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 7:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v2[i] * lh3;
	      temp2 = g_v2[i] * lh2 + g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh4s (float lh1, float *h_v0, float *g_v1, float *g_v2)
{

  int n, j, i;
  float temp1, temp2;

  {
    if (lh1 != 0.0)
      {
	n = 0;
	for (i = 0; i < hess_size_1; i++)
	  {
	    temp1 = g_v2[i] * lh1;
	    temp2 = g_v1[i] * lh1;
	    for (j = 0; j < i + (1 - 0); j++)
	      {
		h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		n = n + 1;
	      }
	  }
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh5s (float lh1, float lh2, float *h_v0, float *g_v1, float *g_v2, float *g_v3)
{

  int iflag, n, j, i;
  float temp1, temp2, temp3;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1;
	      temp2 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v3[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1 + g_v3[i] * lh2;
	      temp2 = g_v1[i] * lh1;
	      temp3 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh6s (float lh1, float lh2, float lh3, float *h_v0, float *g_v1, float *g_v2, float *g_v3, float *g_v4)
{

  int iflag, n, j, i;
  float temp1, temp2, temp3, temp4;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    if (lh3 != 0.0)
      {
	iflag = iflag + 4;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1;
	      temp2 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v3[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1 + g_v3[i] * lh2;
	      temp2 = g_v1[i] * lh1;
	      temp3 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 4:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v4[i] * lh3;
	      temp2 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v4[j];
		  n = n + 1;
		}
	    }
	}
      case 5:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1 + g_v4[i] * lh3;
	      temp2 = g_v1[i] * lh1;
	      temp3 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v4[j];
		  n = n + 1;
		}
	    }
	}
      case 6:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v3[i] * lh2 + g_v4[i] * lh3;
	      temp2 = g_v1[i] * lh2;
	      temp3 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v3[j] + temp3 * g_v4[j];
		  n = n + 1;
		}
	    }
	}
      case 7:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh1 + g_v3[i] * lh2 + g_v4[i] * lh3;
	      temp2 = g_v1[i] * lh1;
	      temp3 = g_v1[i] * lh2;
	      temp4 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v3[j] + temp4 * g_v4[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh7s (float lh1, float lh2, float lh3, float *h_v0, float *g_v1, float *g_v2, float *g_v3)
{

  int iflag, n, j, i;
  float temp1, temp2, temp3, temp4;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    if (lh3 != 0.0)
      {
	iflag = iflag + 4;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v2[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 4:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v3[i] * lh3;
	      temp2 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 5:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v3[i] * lh3;
	      temp2 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 6:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2 + g_v3[i] * lh3;
	      temp2 = g_v1[i] * lh2;
	      temp3 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      case 7:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v2[i] * lh2 + g_v3[i] * lh3;
	      temp2 = g_v1[i] * lh2;
	      temp3 = g_v1[i] * lh3;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j] + temp3 * g_v3[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_accumh8s (float lh1, float lh2, float *h_v0, float *g_v1, float *g_v2)
{

  int iflag, n, j, i;
  float temp1, temp2;

  {
    iflag = 0;
    if (lh1 != 0.0)
      {
	iflag = 1;
      }
    if (lh2 != 0.0)
      {
	iflag = iflag + 2;
      }
    switch (iflag)
      {
      case 1:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j];
		  n = n + 1;
		}
	    }
	}
      case 2:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v2[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      case 3:
	{
	  n = 0;
	  for (i = 0; i < hess_size_1; i++)
	    {
	      temp1 = g_v1[i] * lh1 + g_v2[i] * lh2;
	      temp2 = g_v1[i] * lh2;
	      for (j = 0; j < i + (1 - 0); j++)
		{
		  h_v0[n] = h_v0[n] + temp1 * g_v1[j] + temp2 * g_v2[j];
		  n = n + 1;
		}
	    }
	}
      }
  }
}
#include "hessdef.h"


void 
ad_fh_taddad (double c, double *t_c, double a, double *t_a, double b, double *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i] + t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i] + t_b[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_taddbd (double c, double *t_c, double a, double *t_a, double b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_taddcd (double c, double *t_c, double a, double b, double *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_b[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tsubad (double c, double *t_c, double a, double *t_a, double b, double *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i] - t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i] - t_b[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tsubbd (double c, double *t_c, double a, double *t_a, double b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tsubcd (double c, double *t_c, double a, double b, double *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = -t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = -t_b[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tmulad (double c, double *t_c, double a, double *t_a, double b, double *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = b * t_a[(0 + 1) * hess_maxsize_1 + i] + a * t_b[(0 + 1) * hess_maxsize_1 + i] + t_a[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = b * t_a[(0) * hess_maxsize_1 + i] + a * t_b[(0) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tmulbd (double c, double *t_c, double a, double *t_a, double b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = b * t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = b * t_a[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tmulcd (double c, double *t_c, double a, double b, double *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = a * t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = a * t_b[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tdivad (double c, double *t_c, double a, double *t_a, double b, double *t_b)
{

  int i;
  double temp1, temp2, temp3;

  {
    temp1 = a / b;
    temp2 = 1.0 / b;
    temp3 = temp1 * temp2;
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = temp2 * (t_a[(0 + 1) * hess_maxsize_1 + i] - temp1 * t_b[(0 + 1) * hess_maxsize_1 + i] - temp2 * t_a[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i] - temp3 * t_b[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i]);
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = temp2 * (t_a[(0) * hess_maxsize_1 + i] - temp1 * t_b[(0) * hess_maxsize_1 + i]);
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tdivbd (double c, double *t_c, double a, double *t_a, double b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i] / b;
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i] / b;
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tdivcd (double c, double *t_c, double a, double b, double *t_b)
{

  int i;
  double temp1, temp2;

  {
    temp1 = -a / (b * b);
    temp2 = -temp1 / b;
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = temp1 * t_b[(0 + 1) * hess_maxsize_1 + i] + temp2 * t_b[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = temp1 * t_b[(0) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tcopyd (double c, double *t_c, double a, double *t_a)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tmind (double c, double *t_c, double a, double *t_a)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = -t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = -t_a[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tzerod (double c, double *t_c)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = 0.0;
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = 0.0;
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tintrin1d (double fa, double faa, double c, double *t_c, double a, double *t_a)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = fa * t_a[(0 + 1) * hess_maxsize_1 + i] + 0.5 * faa * t_a[(0) * hess_maxsize_1 + i] * t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = fa * t_a[(0) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tintrin2d (double fa, double fb, double faa, double fab, double fbb, double c, double *t_c, double a, double *t_a, double b, double *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = fa * t_a[(0 + 1) * hess_maxsize_1 + i] + fb * t_b[(0 + 1) * hess_maxsize_1 + i] + 0.5 * faa * t_a[(0) * hess_maxsize_1 + i] * t_a[(0) * hess_maxsize_1 + i] + 0.5 * fbb * t_b[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i] + fab * t_a[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = fa * t_a[(0) * hess_maxsize_1 + i] + fb * t_b[(0) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_taddas (float c, float *t_c, float a, float *t_a, float b, float *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i] + t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i] + t_b[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_taddbs (float c, float *t_c, float a, float *t_a, float b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_taddcs (float c, float *t_c, float a, float b, float *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_b[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tsubas (float c, float *t_c, float a, float *t_a, float b, float *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i] - t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i] - t_b[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tsubbs (float c, float *t_c, float a, float *t_a, float b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tsubcs (float c, float *t_c, float a, float b, float *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = -t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = -t_b[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tmulas (float c, float *t_c, float a, float *t_a, float b, float *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = b * t_a[(0 + 1) * hess_maxsize_1 + i] + a * t_b[(0 + 1) * hess_maxsize_1 + i] + t_a[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = b * t_a[(0) * hess_maxsize_1 + i] + a * t_b[(0) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tmulbs (float c, float *t_c, float a, float *t_a, float b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = b * t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = b * t_a[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tmulcs (float c, float *t_c, float a, float b, float *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = a * t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = a * t_b[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tdivas (float c, float *t_c, float a, float *t_a, float b, float *t_b)
{

  int i;
  float temp1, temp2, temp3;

  {
    temp1 = a / b;
    temp2 = 1.0 / b;
    temp3 = temp1 * temp2;
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = temp2 * (t_a[(0 + 1) * hess_maxsize_1 + i] - temp1 * t_b[(0 + 1) * hess_maxsize_1 + i] - temp2 * t_a[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i] - temp3 * t_b[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i]);
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = temp2 * (t_a[(0) * hess_maxsize_1 + i] - temp1 * t_b[(0) * hess_maxsize_1 + i]);
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tdivbs (float c, float *t_c, float a, float *t_a, float b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i] / b;
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i] / b;
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tdivcs (float c, float *t_c, float a, float b, float *t_b)
{

  int i;
  float temp1, temp2;

  {
    temp1 = -a / (b * b);
    temp2 = -temp1 / b;
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = temp1 * t_b[(0 + 1) * hess_maxsize_1 + i] + temp2 * t_b[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = temp1 * t_b[(0) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tcopys (float c, float *t_c, float a, float *t_a)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = t_a[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tmins (float c, float *t_c, float a, float *t_a)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = -t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = -t_a[(0 + 1) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tzeros (float c, float *t_c)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = 0.0;
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = 0.0;
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tintrin1s (float fa, float faa, float c, float *t_c, float a, float *t_a)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = fa * t_a[(0 + 1) * hess_maxsize_1 + i] + 0.5 * faa * t_a[(0) * hess_maxsize_1 + i] * t_a[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = fa * t_a[(0) * hess_maxsize_1 + i];
      }
  }
}
#include "hessdef.h"


void 
ad_fh_tintrin2s (float fa, float fb, float faa, float fab, float fbb, float c, float *t_c, float a, float *t_a, float b, float *t_b)
{

  int i;

  {
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0 + 1) * hess_maxsize_1 + i] = fa * t_a[(0 + 1) * hess_maxsize_1 + i] + fb * t_b[(0 + 1) * hess_maxsize_1 + i] + 0.5 * faa * t_a[(0) * hess_maxsize_1 + i] * t_a[(0) * hess_maxsize_1 + i] + 0.5 * fbb * t_b[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i] + fab * t_a[(0) * hess_maxsize_1 + i] * t_b[(0) * hess_maxsize_1 + i];
      }
    for (i = 0; i < hess_size_1; i++)
      {
	t_c[(0) * hess_maxsize_1 + i] = fa * t_a[(0) * hess_maxsize_1 + i] + fb * t_b[(0) * hess_maxsize_1 + i];
      }
  }
}
