#include "mempool.h"

#define max(a,b) (a > b ? a : b)

int mp_init(mempool *mp, int size) {
  void *temp, *end;

  mp->freelist = (void *)mp->pool;

  mp->size = max(size, sizeof(void*));
  end = mp->freelist + POOL_SIZE - mp->size;
  for(temp = mp->freelist; temp < end;
      temp += mp->size) {
    *((void **)temp) = temp + mp->size;
  }
  *((void **)temp) = NULL;

  mp->next = NULL;

  /*
  for(temp = mp->freelist; temp != NULL; temp = *((void **)temp))
    fprintf(stdout, "%p -> %p\n", temp, *((void **)temp));
  */

  return 1;
}

int mp_grow(mempool *mp) {
  mempool *temp;
  void *ptr;

  if(mp == NULL) return 0;

  for(temp = mp; temp->next != NULL; temp = temp->next);
  temp->next = (mempool *)malloc(sizeof(mempool));
  temp = temp->next;
  if(temp == NULL) return 0;

  mp_init(temp, mp->size);

  if(mp->freelist == NULL) mp->freelist = temp->freelist;
  else {
    for(ptr = mp->freelist; *((void **)ptr) != NULL; ptr = *((void **)ptr));
    *((void **)ptr) = temp->freelist;
  }

  return 1;
}

void *mp_alloc(mempool *mp) {
  void *temp;

  if(mp->freelist == NULL) mp_grow(mp);

  temp = mp->freelist;

  if(temp != NULL)
    mp->freelist = *((void **)temp);

  return temp;
}

void **mp_allocn(mempool *mp, int n, void **diarray) {
  int i;

  for(i = 0; i < n; i++) {
    if(mp->freelist == NULL) mp_grow(mp);
    diarray[i] = mp->freelist;
    mp->freelist = *((void **)mp->freelist);
  }

  return diarray;
}

void mp_free(mempool *mp, void *ptr) {
  *((void **)ptr) = mp->freelist;
  mp->freelist = ptr;
}

void mp_freen(mempool *mp, int n, void **diarray) {
  int i;

  for(i = n-1; i >= 0; i--) {
    *((void **)diarray[i]) = mp->freelist;
    mp->freelist = diarray[i];
  }
}

void mp_dumpfree(FILE *fstream, mempool *mp) {
  void *temp;

  for(temp = mp->freelist; temp != NULL; temp = *((void **)temp))
    fprintf(fstream, "%p -> %p\n", temp, *((void **)temp));
}

void mp_destroy(mempool *mp) {
  mempool *temp = mp->next, *nextinline;

  mp->freelist = NULL;

  while (temp != NULL) {
    nextinline = temp->next;
    free(temp);
    temp = nextinline;
  }  
}

