
#line 777 "ad_adj.w"
#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h>
#include <assert.h>
#include "ad_adj.h"


#line 109 "ad_adj.w"
enum {
   OP_ASSIGN_ZERO = 1,
   OP_ASSIGN_COPY,
   OP_ASSIGN_ONE,
/*
   OP_ASSIGN_TWO,
   OP_ASSIGN_THREE,
 */
   OP_ASSIGN,
};

#define STACK_OFFSET 	1024


#line 206 "ad_adj.w"
#define MODIFIER_OFFSET	3
#define MODIFIER_MASK	((1<<MODIFIER_OFFSET) - 1)
#define OPCODE_BUFSIZE	102400

static FILE* pfd_op = 0;
static unsigned char bufOp[OPCODE_BUFSIZE];
static int countOp = 0;
static int tape_on = 0;


#line 279 "ad_adj.w"
#define ADDR_BUFSIZE	102400

static FILE* pfd_addr = 0;
static FLOAT* bufAddr[ADDR_BUFSIZE];
static int countAddr = 0;



#line 361 "ad_adj.w"
#define ALPHA_BUFSIZE	102400

static FILE* pfd_alpha = 0;
static FLOAT bufAlpha[ALPHA_BUFSIZE];
static int countAlpha = 0;



#line 594 "ad_adj.w"
static char* stack_low = 0;
static char* stack_high = 0;



#line 624 "ad_adj.w"
static char* heap_low = 0;
static char* heap_high = 0;


#line 138 "ad_adj.w"
FILE* ad_tape_open(const char* name)
{
    FILE* pfd = fopen(name, "wb+");
    if (!pfd) {
	printf("Cannot open file: %s\n", name);
	exit(1);
    }
    return pfd;
}


void ad_tape_rev_start(FILE* pfd)
{
    if (fseek(pfd, 0L, SEEK_END)) {
	printf("Cannot seek to end\n");
	exit(1);
    }
}


void ad_tape_write(FILE* pfd, void* buf, int bytes)
{
    int n = fwrite(buf, bytes, 1, pfd);
    if (n != 1) {
	printf("Cannot write file\n");
	exit(1);
    }
}


int ad_tape_read(FILE* pfd, void* buf, int bytes)
{
    int n, err;
    if ((n = ftell(pfd)) < bytes) {
        bytes = n;
    }
    if (fseek(pfd, (long)-bytes, SEEK_CUR)) {
	printf("Cannot seek to end");
	exit(1);
    }
    n = fread(buf, 1, bytes, pfd);
    fseek(pfd, (long)-bytes, SEEK_CUR);
    return n;
}



void tape_read_forward();
void tape_read_reverse();
void tape_end();
void tape_begin();




#line 217 "ad_adj.w"
void ad_tape_open_op()
{
    countOp = 0;
    pfd_op = ad_tape_open(".adic.tape.op");
}

void ad_tape_start_op()
{
    countOp = 0;
}

void ad_tape_rev_start_op()
{
    countOp = 0;
    ad_tape_rev_start(pfd_op);
}

void ad_tape_put_op(int op, int count)
{
    bufOp[countOp++] = (op | count<<MODIFIER_OFFSET);
    if (countOp >= OPCODE_BUFSIZE) {
	ad_tape_write(pfd_op, bufOp, OPCODE_BUFSIZE);
	countOp = 0;
    }
}

void ad_tape_stop_op()
{
    if (countOp > 0) {
	ad_tape_write(pfd_op, bufOp, countOp);
	countOp = 0;
    }
    fflush(pfd_op);
}


int ad_tape_get_op(int* count)
{
    int tmp;
    if (countOp <= 0) {
	countOp = ad_tape_read(pfd_op, bufOp, OPCODE_BUFSIZE);
    }
    tmp = bufOp[--countOp];
    *count = tmp>>MODIFIER_OFFSET;
    return tmp & MODIFIER_MASK;
}
    


#line 288 "ad_adj.w"
void ad_tape_open_addr()
{
    countAddr = 0;
    pfd_addr = ad_tape_open(".adic.tape.addr");
}

void ad_tape_start_addr()
{
    countAddr = 0;
}

void ad_tape_rev_start_addr()
{
    countAddr = 0;
    ad_tape_rev_start(pfd_addr);
}

void ad_tape_put_addr(double* pa)
{
    return;
    bufAddr[countAddr++] = (FLOAT*)pa;
    if (countAddr >= ADDR_BUFSIZE) {
	ad_tape_write(pfd_addr, bufAddr, sizeof(FLOAT*)*ADDR_BUFSIZE);
	countAddr = 0;
    }
}

void ad_tape_stop_addr()
{
    if (countAddr > 0) {
	ad_tape_write(pfd_addr, bufAddr, sizeof(FLOAT*)*countAddr);
	countAddr = 0;
    }
    fflush(pfd_addr);
}


double* ad_tape_get_addr()
{
    FLOAT* x;
    if (countAddr <= 0) {
	countAddr = ad_tape_read( pfd_addr, bufAddr, 
			  sizeof(FLOAT*)*ADDR_BUFSIZE ) / sizeof(FLOAT*);
	if (!countAddr) {
	    printf("Error: null get addr\n");
	    exit(1);
        }
    }
    x = bufAddr[--countAddr];
    if (x >= (FLOAT*)stack_low && x <= (FLOAT*)stack_high) {
/***WARNING***************************************/
/*************************************************/
/**	x -= STACK_OFFSET;***********************************************/
/*************************************************/
	x += STACK_OFFSET;
    }
    return (double*)x;
}
    



#line 370 "ad_adj.w"
void ad_tape_open_alpha()
{
    countAlpha = 0;
    pfd_alpha = ad_tape_open(".adic.tape.alpha");
}

void ad_tape_start_alpha()
{
    countAlpha = 0;
}

void ad_tape_rev_start_alpha()
{
    countAlpha = 0;
    ad_tape_rev_start(pfd_alpha);
}

void ad_tape_put_alpha(double alpha)
{
    bufAlpha[countAlpha++] = (FLOAT)alpha;
    if (countAlpha >= ALPHA_BUFSIZE) {
	ad_tape_write(pfd_alpha, bufAlpha, sizeof(FLOAT)*ALPHA_BUFSIZE);
	countAlpha = 0;
    }
}

void ad_tape_stop_alpha()
{
    if (countAlpha > 0) {
	ad_tape_write(pfd_alpha, bufAlpha, sizeof(FLOAT)*countAlpha);
	countAlpha = 0;
    }
    fflush(pfd_alpha);
}


double ad_tape_get_alpha()
{
    if (countAlpha <= 0) {
	countAlpha = ad_tape_read( pfd_alpha, bufAlpha, 
                          sizeof(FLOAT)*ALPHA_BUFSIZE ) / sizeof(FLOAT);
    }
    return (FLOAT)bufAlpha[--countAlpha];
}
    




#line 431 "ad_adj.w"
void ad_adj_axpy_0(double* dz)
{
    if (tape_on) {
        ad_tape_put_op(OP_ASSIGN_ZERO, 0);
        ad_tape_put_addr(dz);
    }
}

void ad_adj_axpy_copy(double* dz, double* dx)
{
    int	    i;
    FLOAT  alpha, *loc;
    va_list ap;
    va_start(ap, dz);

    if (tape_on) {
        ad_tape_put_op(OP_ASSIGN_COPY, 0);
        ad_tape_put_addr(dx);
        ad_tape_put_addr(dz);
    }
}

void ad_adj_axpy_1(double* dz, double alpha, double* da)
{
    int	    i;
    if (tape_on) {
	if (alpha == 0.0) {
	    i = 1;
        }
	else if (alpha == 1.0) {
	    i = 2;
        }
	else {
	    ad_tape_put_alpha(alpha);
	    i = 3;
        }
        ad_tape_put_op(OP_ASSIGN_ONE, i);
        ad_tape_put_addr(da);
        ad_tape_put_addr(dz);
    }
}


void ad_adj_axpy_n(int arity, double* dz, ...)
{
    int	    i;
    FLOAT  alpha, *loc;
    va_list ap;
    va_start(ap, dz);

    if (tape_on) {
        ad_tape_put_op(OP_ASSIGN, arity);
        for (i=0; i < arity; i++) {
	    alpha = va_arg(ap, FLOAT);
	    loc = va_arg(ap, FLOAT*);
	    if (alpha == 0.0) {
	        loc = (FLOAT*)((int)loc | 1);
            }
	    else {
	        ad_tape_put_alpha(alpha);
            }
	    ad_tape_put_addr((double*)loc);
        }
        ad_tape_put_addr(dz);
    }
    va_end(ap);
}



#line 509 "ad_adj.w"
void ad_adj_reverse()
{
    int		i, mod, op;
    FLOAT	alpha, dz, *loc, *z, *a, *b, *c, *d;

    ad_tape_stop_alpha();
    ad_tape_stop_op();
    ad_tape_stop_addr();
    
    ad_tape_rev_start_alpha();
    ad_tape_rev_start_op();
    ad_tape_rev_start_addr();

    nullMemory();

    while (op = ad_tape_get_op(&mod)) {
	switch (op) {
	  case OP_ASSIGN_ZERO:
            *ad_tape_get_addr() = 0.0;
	    printf("Z:%d %.3f\n", z, *z);
	    break;

	  case OP_ASSIGN_COPY:
            z = (FLOAT*)ad_tape_get_addr();
            printf("C:%d %.3f\n", z, *z);
	    dz = *z;		
            *z = 0.0;
	    *ad_tape_get_addr() += dz;
	    break;

	  case OP_ASSIGN_ONE:
            z = (FLOAT*)ad_tape_get_addr();
            printf("1:%d %.3f\n", z, *z);
	    dz = *z;		
            *z = 0.0;
	    if (mod == 1) {
	        alpha = 0.0;
            }
	    else if (mod == 2) {
	        alpha = 1.0;
            }
	    else {
	        alpha = ad_tape_get_alpha();
            }
	    *ad_tape_get_addr() += alpha * dz;
	    break;

	  case OP_ASSIGN:
            z = (FLOAT*)ad_tape_get_addr();
            printf("%d:%d %.3f\n", mod, z, *z);
	    dz = *z;		
            *z = 0.0;
	    for (i = 0; i < mod; i++) {
	        loc = (FLOAT*)ad_tape_get_addr();
	        if ((int)loc & 1) {
		    loc = (FLOAT*)((int)loc & ~1);
	            alpha = 0.0;
                }
	        else {
		    alpha = ad_tape_get_alpha();
                }
	        *loc += alpha * dz;
            }
	    break;

          default:
	    printf("Unknown tape op: %d\n", op);
	    exit(1);
        }
    }
}
	



#line 600 "ad_adj.w"
void ad_adj_enter()
{
    char    local;
    if (!stack_low || &local < (char*)stack_low) {
	stack_low = &local;
    }
    else if (&local > (char*)stack_high) {
	stack_high = &local;
    }
}



#line 629 "ad_adj.w"
void* ad_adj_malloc(size_t size)
{
    char* p = (char*)malloc(size);
    if (!heap_low || p < heap_low) {
	heap_low = p;
    }
    if (p+size > heap_high) {
	heap_high = p;
    }
    return p;
}



#line 644 "ad_adj.w"
void* ad_adj_calloc(size_t size, size_t elsize)
{
    char* p = (char*)calloc(size, elsize);
    if (!heap_low || p < heap_low) {
	heap_low = p;
    }
    if (p+size*elsize > heap_high) {
	heap_high = p;
    }
    return p;
}



#line 659 "ad_adj.w"
void* ad_adj_realloc(void* ptr, size_t size)
{
    char* p = (char*)realloc(ptr, size);
    if (!heap_low || p < heap_low) {
	heap_low = p;
    }
    if (p+size > heap_high) {
	heap_high = p;
    }
    return p;
}


void ad_adj_free(void* p)
{
    free(p);
}





#line 691 "ad_adj.w"
void nullMemory()
{
    if (heap_low) {
        memset(heap_low, '\0', heap_high - heap_low);
    }

    if (stack_high) {
        memset( stack_low + sizeof(FLOAT)*STACK_OFFSET, 
	        '\0', stack_high - stack_low );
    }
}





#line 716 "ad_adj.w"
void ad_adj_init()
{
    char    local;

    ad_tape_open_op();
    ad_tape_open_addr();
    ad_tape_open_alpha();
}


void ad_adj_final()
{
}





#line 738 "ad_adj.w"
void ad_adj_set_seed(double* ploc, double d)
{
    *ploc = d;
}
    

void ad_adj_extract(double* ploc, double* padj)
{
    *padj = *ploc;
}


void ad_adj_var_init(void *x, int size)
{
    memset(x, '\0', size);
}
    

void ad_adj_tape_on()
{
    tape_on = 1;
}

void ad_adj_tape_off()
{
    tape_on = 0;
}



