extern int hess_size_1, hess_size_2;

void ad_unlinearize_hessiand(double* linear, double *square) 
{
  int i, j;

  for (i=0; i<hess_size_1; i++) {
    for (j=0; j<i+1; j++) {
      square[i*hess_size_1+j] = linear[j+i*(i+1)/2];
      square[j*hess_size_1+i] = square[i*hess_size_1+j];
    }
  }
}

/*======================================================================*/

void ad_unlinearize_hessians(float* linear, float *square) 
{
  int i, j;

  for (i=0; i<hess_size_1; i++) {
    for (j=0; j<i+1; j++) {
      square[i*hess_size_1+j] = linear[j+i*(i+1)/2];
      square[j*hess_size_1+i] = square[i*hess_size_1+j];
    }
  }
}

/*======================================================================*/

/*
C======================================================================

      subroutine ad_complete_taylor_map(nvars, map, ld_map, length)
      integer nvars, ld_map, map(ld_map,*), length

      do i=1, nvars
         do j=1, nvars

C     Reflect to produce symmetric map, if necessary
            if (map(i,j) .eq. 1) then
               map(j,i) = 1
            end if

C     Set required diagonal elements
            if (map(i,j) .eq. 1 .and. map(i,i) .ne. -1) then
               map(i,i) = 1
            end if
            if (map(i,j) .eq. 1 .and. map(j,j) .ne. -1) then
               map(j,j) = 1
            end if
         end do
      end do

C     Remove -1s from map
      do i=1, nvars
         do j=1, nvars
            if (map(i,j) .eq. -1) then
               map (i,j) = 0
            end if
         end do
      end do

C     Number map and determine required length of Taylor series vector
      length = 1
      do i=1, nvars
         do j=1, i
            if (map(i,j) .eq. 1) then
               map(i,j) = length
               map(j,i) = length
               length = length + 1
            end if
         end do
      end do

C     Decrement length by one to be correct
      length = length - 1
      
      return
      end

C======================================================================

      subroutine ad_init_taylord(nvars, len, n, vector, map, ld_map)
      integer nvars, len, n, ld_map, map(ld_map,*)
      double precision vector(*)

      do i=1, len
         vector(i) = 0.0
      end do

      do i=1, nvars
         if (map(i,n) .ne. 0) then
            vector(map(i,n)) = 1.0
         end if
      end do

      return
      end                   

C======================================================================

      subroutine ad_init_taylors(nvars, len, n, vector, map, ld_map)
      integer nvars, len, n, ld_map, map(ld_map,*)
      real vector(*)

      do i=1, len
         vector(i) = 0.0
      end do

      do i=1, nvars
         if (map(i,n) .ne. 0) then
            vector(map(i,n)) = 1.0
         end if
      end do

      return
      end                   

C======================================================================

      subroutine ad_interp_taylord(nvars, map, ld_map, vector,
     $     ld_vector, grad, hess, ld_hess)
      integer nvars, ld_map, ld_vector, ld_hess, map(ld_map,*)
      double precision vector(ld_vector,2), grad(*), hess(ld_hess,*)

C     Zero the gradient and Hessian
      do i=1, nvars
         grad(i) = 0.0
         do j=1, nvars
            hess(j,i) = 0.0
         end do
      end do

      do i=1, nvars
         if (map(i,i) .ne. 0) then
            grad(i) = vector(map(i,i),1)
         end if
         do j=1, i
            if (map(j,i) .ne. 0) then
C     Diagonal entry
               if (i .eq. j) then
                  hess(j,i) = 2.0*vector(map(j,i),2)
               else 
C     Off-diagonal entry 
                  if (map(i,i) .ne. 0 .and. map(j,j) .ne. 0) then
                     hess(j,i) = vector(map(j,i),2) - vector(map(i,i),2)
     $                    -vector(map(j,j),2)
                     hess(i,j) = hess(j,i)
                  else if (map(i,i) .ne. 0) then
                     hess(j,i) = vector(map(j,i),2) - vector(map(i,i),2)
                     hess(i,j) = hess(j,i)
                  else if (map(j,j) .ne. 0) then 
                     hess(j,i) = vector(map(j,i),2) - vector(map(j,j),2)
                     hess(i,j) = hess(j,i)
                  else
                     hess(j,i) = vector(map(j,i),2)
                     hess(i,j) = hess(j,i)
                  end if
               end if
            end if
         end do
      end do

      return
      end

C======================================================================

      subroutine ad_interp_taylors(nvars, map, ld_map, vector,
     $     ld_vector, grad, hess, ld_hess)
      integer nvars, ld_map, ld_vector, ld_hess, map(ld_map,*)
      real vector(ld_vector,2), grad(*), hess(ld_hess,*)

C     Zero the gradient and Hessian
      do i=1, nvars
         grad(i) = 0.0
         do j=1, nvars
            hess(j,i) = 0.0
         end do
      end do

      do i=1, nvars
         if (map(i,i) .ne. 0) then
            grad(i) = vector(map(i,i),1)
         end if
         do j=1, i
            if (map(j,i) .ne. 0) then
C     Diagonal entry
               if (i .eq. j) then
                  hess(j,i) = 2.0*vector(map(j,i),2)
               else 
C     Off-diagonal entry 
                  if (map(i,i) .ne. 0 .and. map(j,j) .ne. 0) then
                     hess(j,i) = vector(map(j,i),2) - vector(map(i,i),2)
     $                    -vector(map(j,j),2)
                     hess(i,j) = hess(j,i)
                  else if (map(i,i) .ne. 0) then
                     hess(j,i) = vector(map(j,i),2) - vector(map(i,i),2)
                     hess(i,j) = hess(j,i)
                  else if (map(j,j) .ne. 0) then 
                     hess(j,i) = vector(map(j,i),2) - vector(map(j,j),2)
                     hess(i,j) = hess(j,i)
                  else
                     hess(j,i) = vector(map(j,i),2)
                     hess(i,j) = hess(j,i)
                  end if
               end if
            end if
         end do
      end do

      return
      end

C======================================================================

*/
