use Exporter;

package Template::Input;

@ISA = qw(Exporter);
@EXPORT = qw(load_template_file);
@EXPORT_OK = qw(read_template_file);

use TemplateFile;
use LineInFile;
use PurseErrors qw(:DEFAULT $line_in_template);
use Template::Find qw(find_template_file);
use commabreak;
#require 'commabreak.pl'; # could ``use'' if you want to use CommaBreak 1.01

{
    $function_string = 'function name';
    $exceptional_values_string = 'exceptional values';
    $exceptional_code_string = 'exceptional code';
    $template_string = 'template';
}
sub read_template_file
{
    my ($FILE) = @_;
    
    my (@raw_lines);
    my ($line_num) = 0;

    # For classification
    my (@sec_function, @sec_exceptional_values, @sec_exceptional_code,
        @sec_template, @sec_ignore);

    my ($sec_current);

    # For function, number of args
    my ($function, $number_of_args);

    while(<$FILE>)
    {
        chomp;
        $line_num++;
        push(@raw_lines, LineInFile->new($_, $line_num));
    }

{
    $sec_current = \@sec_ignore;
    my ($current_line);

    while(@raw_lines)
    {
        $current_line = shift(@raw_lines);
        $_ = $current_line->Text();

        if ( m/^\s*${function_string}\s*:/io )
        {
            $sec_current = \@sec_function;
        } 
        elsif ( m/^\s*${exceptional_code_string}\s*:/io )
        {
            $sec_current = \@sec_exceptional_code;
        } 
        elsif ( m/^\s*${exceptional_values_string}\s*:/io )
        {
            $sec_current = \@sec_exceptional_values;
        } 
        elsif ( m/^\s*${template_string}\s*:/io )
        {
            $sec_current = \@sec_template;
        } 
        else
        {        
            push(@$sec_current, $current_line);
        }
    }
}
{
    my($current_line) = @sec_function[0];

    if ( ! defined ($current_line) )
    {
        $line_in_template = "UNKNOWN";
        &die_template_problem ("Did not find a `function name' section in template");
    }

    
    $_ = $current_line->Text();
    $line_in_template = $current_line->LineNumber();

    my(@parsed_args);
    
    # Trim whitespace
     s/^\s*//;
    s/\s*$//;
    
    # Decide how many arguments it has.
    @parsed_args = &commabreak($_);
    # pop(@parsed_args); leaving on the \000 means 1 args -> $# = 1
    
    if ( $#parsed_args == 1 ) {
        $number_of_args = 1;
    } elsif ( $#parsed_args == 2 ) {
        $number_of_args = 2;
    } else {
        $number_of_args = undef;
        &die_template_problem("Either cannot decide how many arguments function takes, or it does not take 1 or 2 arguments", $current_line);
    }

    # Make sure the arguments are "x" and "y".
    if ( ($parsed_args[0] !~ m/\s*x\s*/)
        || (($number_of_args == 2)
            && ($parsed_args[1] !~ m/\s*y\s*/ )
            )
        )
    {
        &die_template_problem("Dummy arguments in template line required to be `x' and `y'", $current_line);
    }

    # Pick off function name -- the stuff before the parentheses
    m/^\s*([^() ]*)/;
    $function = $1;
}

    $template = new TemplateFile
        ($function, $number_of_args,
         \@sec_function,
         \@sec_exceptional_values,
         \@sec_exceptional_code,
         \@sec_template);

    return ($template);
}

sub load_template_file {
    my ($template_name) = @_;
    my $fullpath;
    my $result;

    $fullpath = &find_template_file($template_name);

    open(TEMPLATE_FILE,"<$fullpath") ||
        &die_input_problem("Found template `$template_name' at `$fullpath' but could not open it");

    $result = &read_template_file(\*TEMPLATE_FILE);
    close(TEMPLATE_FILE) || 
        &warn_input_problem ("Unable to close template file `$fullpath' for some reason");

    return $result;
}

1;

