#include "ad_support.h"
#include "nvector.h"
#include FUNC_H

/* specify AD code or shells of original code */

#ifdef USE_AD
  #define FDQ_ad FDQ
#else
  #define FDQ_shell FDQ
#endif

/************* Prototype **************************/

void FDQ_orig(integer Ntotal, real t, N_Vector u, N_Vector udot,
                void *s_data);


/**************************************************/

void ad_NVector_transfer_in(N_Vector x, ad_N_Vector y)
{
int i;

y->length = x->length;
y->global_length = x->global_length;
y->machEnv = x->machEnv; /* sloppy - could cause dangling references - PDH */

/* not sure what to initialize subptr to, copying from x, assigning NULL causes SEGV */

for(i=0;i<x->length;i++)
  {
    DERIV_val(y->data[i]) = x->data[i];
  }
}

void ad_NVector_transfer_out(ad_N_Vector x, N_Vector y)
{
int i;

y->length = x->length;
y->global_length = x->global_length;
y->machEnv = x->machEnv; /* sloppy - could cause dangling references - PDH */

/* not sure what to initialize subptr to, copying from x, assigning NULL causes SEGV */

for(i=0;i<x->length;i++)
  {
    y->data[i] = DERIV_val(x->data[i]); 
  }
}

void ad_NVector_transfer_grads(int ns,ad_N_Vector x, N_Vector *y)
{
int i,j;

for(i=0;i<ns;i++)
  for(j=0;j<x->length;j++) 
    y[i+1]->data[j] = DERIV_grad(x->data[j])[i];
}

/* Slight overhead for shell */

void FDQ_shell(integer Ntotal, nosens_real t, N_Vector u, N_Vector udot, 
                void *s_data)
{
  FDQ_orig(Ntotal, t, u, udot, s_data);
}

void FDQ_ad(integer Ntotal, nosens_real t, N_Vector u, N_Vector udot,
                void *s_data)
{
ad_N_Vector ad_u, ad_udot;
ad_UserData ad_data;
SensData sdata;
UserData data;
N_Vector *usub, *udotsub;

int i,j,ns,ny,localy;

sdata = (SensData ) s_data;
data = sdata->f_data;

/* Are these casts needed? */

ad_data = (ad_UserData) sdata->ad_data;
ad_u = (ad_N_Vector) sdata->ad_u;
ad_udot = (ad_N_Vector) sdata->ad_udot;

ns = sdata->ns;
ny = sdata->ny;
usub = (N_Vector *) u->subptr;
udotsub = (N_Vector *) udot->subptr;
localy = usub[0]->length;

ad_NVector_transfer_in(usub[0],ad_u);
ad_NVector_transfer_in(udotsub[0],ad_udot);

ad_AD_ResetIndep();
ad_AD_SetIndepArray(ad_data->p,ns)
ad_AD_SetIndepDone();

for(i=0;i<ns;i++){
  DERIV_grad(ad_data->p[i])[i] = data->pbar[i];
  for(j=0;j<localy;j++) DERIV_grad(ad_u->data[j])[i] = usub[i+1]->data[j];
}

ad_f(ny,t,ad_u,ad_udot,ad_data);

ad_NVector_transfer_out(ad_udot,udotsub[0]);
ad_NVector_transfer_grads(ns,ad_udot,udotsub);
}

void ad_Malloc(SensData sens, int N, machEnvType m) {

ad_UserData ad_data;
ad_N_Vector ad_u, ad_udot;

ad_data = (ad_UserData) malloc(sizeof(*ad_data));
ad_data->p = (DERIV_TYPE *) malloc(NP*sizeof(DERIV_TYPE));
ad_data->pbar = (DERIV_TYPE *) malloc(NP*sizeof(DERIV_TYPE));
ad_u = ad_N_VNew(N,m); 
ad_udot = ad_N_VNew(N,m);

sens->ad_data = ad_data;
sens->ad_u = ad_u;
sens->ad_udot = ad_udot;

/* This next call should be via a function pointer or something */
ad_copy_data(sens->f_data, sens->ad_data, sens->ns);
}

void ad_Free(SensData sens){

ad_UserData ad_data;

ad_data = (ad_UserData) sens->ad_data;
free(ad_data->pbar);
free(ad_data->p);
free(sens->ad_data);
ad_N_VFree(sens->ad_udot);
ad_N_VFree(sens->ad_u);
}
